@@ -115,7 +115,7 @@ my %formats = (
     } );
 
 
-sub request_xml {
+sub _request_xml {
     my ($self, $method, $args) = @_;
 
     if ( $args->{cli} && ( ! $args->{Telephone} ) ) {
@@ -172,7 +172,7 @@ sub request_xml {
     return $xml;
 }
 
-sub make_request {
+sub _make_request {
     my ($self, $method, $data) = @_;
 
     my $ua = new LWP::UserAgent;
@@ -186,7 +186,7 @@ sub make_request {
     $url = ENDPOINT . "xml/AdslProductChange" . '.php' if $method eq "ProductChange";
     if ( $enta_xml_methods{$method} ) {     
         push @{$ua->requests_redirectable}, 'POST';
-        my $xml = $self->request_xml($method, $data);
+        my $xml = $self->_request_xml($method, $data);
 
         $body .= "--" . BOUNDARY . "\n";
         $body .= "Content-Disposition: form-data; name=\"userfile\"; filename=\"XML.data\"\n";
@@ -253,7 +253,7 @@ sub make_request {
     return $resp_o;
 }
 
-sub convert_input {
+sub _convert_input {
     my ($self, $method, $args) = @_;
     die "convert_input called without method or args hashref" unless $method && ref $args eq 'HASH';
 
@@ -280,7 +280,7 @@ sub convert_input {
     return $data;
 }
 
-sub serviceid {
+sub _serviceid {
     my ( $self, $args ) = @_;
     
     die "You must supply the service-id parameter" unless 
@@ -432,7 +432,7 @@ sub adslchecker {
         "Version" => 4
         } ;
 
-    my $response = $self->make_request("ADSLChecker", $data);
+    my $response = $self->_make_request("ADSLChecker", $data);
 
     my %results = ();
     foreach (keys %{$response->{Response}->{OperationResponse}}) {
@@ -462,7 +462,7 @@ sub username_available {
     my ($self, $username) = @_;
     die "You must provide the username parameter" unless $username;
 
-    my $response = $self->make_request("CheckUsernameAvailable", 
+    my $response = $self->_make_request("CheckUsernameAvailable", 
         { "username" => $username } );
 
     return undef if $response->{Response}->{OperationResponse}->{Available} eq "false";
@@ -506,8 +506,8 @@ sub interleaving_status {
     my ( $self, %args ) = @_;
     $self->_check_params(\%args, qw/service-id|username|telephone|ref/);
 
-    my $data = $self->serviceid(\%args);
-    my $response = $self->make_request("GetInterleaving", $data);
+    my $data = $self->_serviceid(\%args);
+    my $response = $self->_make_request("GetInterleaving", $data);
 
     return $response->{Response}->{OperationResponse}->{Interleave};
 
@@ -528,7 +528,7 @@ sub interleaving {
     die "interleaving can only be 'Yes', 'No' or 'Auto'" unless
         $args{"interleaving"} =~ /(Yes|No|Auto)/;
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     $data->{"LineFeatures"}->{"Interleaving"} = $args{"interleaving"};
 
     return $self->modifylinefeatures( %$data );
@@ -549,7 +549,7 @@ sub stabilityoption {
     die "option can only be 'Standard', 'Stable', or 'Super Stable'" unless
         $args{"option"} =~ /(Standard|Stable|Super Stable)/;
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     $data->{"LineFeatures"}->{"StabilityOption"} = $args{"option"};
 
     return $self->modifylinefeatures( %$data );
@@ -573,7 +573,7 @@ sub elevatedbestefforts {
     die "option can only be 'Yes' or 'No'" unless
         $args{option} =~ /(Yes|No)/;
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
 
     $data->{"LineFeatures"}->{"ElevatedBestEfforts"} = $args{"option"};
     $data->{"LineFeatures"}->{"ElevatedBestEffortsFee"} = $args{"fee"}
@@ -582,9 +582,9 @@ sub elevatedbestefforts {
     return $self->modifylinefeatures( %$data );
 }
 
-=head2 change_carelevel
+=head2 care_level
 
-    $enta->carei_level( "service-id" -> "ADSL12345", "care-level" => "enhanced" );
+    $enta->care_level( "service-id" -> "ADSL12345", "care-level" => "enhanced" );
 
 Changes the care-level associated with a given service. 
 
@@ -623,7 +623,7 @@ sub enhanced_care {
 
     die "option can only be 'On' or 'Off'" unless $args{option} =~ /(On|Off)/;
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     my $ec = 4 if $args{option} eq 'On';
     $ec = 5 if $args{option} eq 'Off';
 
@@ -661,10 +661,10 @@ sub modifylinefeatures {
     my ($self, %args) = @_;
     $self->_check_params(\%args, ("service-id|ref|telephone|username", "LineFeatures"));
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     $data->{"LineFeatures"} = $args{"LineFeatures"};
 
-    my $response = $self->make_request("ModifyLineFeatures", $data);
+    my $response = $self->_make_request("ModifyLineFeatures", $data);
 
     my %return = ();
     foreach ( keys %{$response->{Response}->{OperationResponse}->{ADSLAccount}->{LineFeatures}} ) {
@@ -748,7 +748,7 @@ sub getbtfeed {
     my ($self, %args) = @_;
     $self->_check_params(\%args, (qw/days/));
 
-    my $response = $self->make_request("GetBTFeed", { "Days" => $args{days} });
+    my $response = $self->_make_request("GetBTFeed", { "Days" => $args{days} });
 
     my @records = ();
     while ( my $r = pop @{$response->{Response}->{OperationResponse}->{Records}->{Record}} ) {
@@ -779,12 +779,12 @@ sub update_contact {
     my ( $self, %args) = @_;
     $self->_check_params(\%args);
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     for (qw/Email TelDay TelEve/) {
         $data->{$_} = $args{lc $_} if $args{lc $_};
     }
 
-    my $response = $self->make_request("UpdateADSLContact", $data);
+    my $response = $self->_make_request("UpdateADSLContact", $data);
     return 1;
 }
 
@@ -802,7 +802,7 @@ sub cease {
 
     my $data = undef;
     if ( $args{'service-id'} || $args{'ref'} ) {
-        $data = $self->convert_input("CeaseADSLOrder" ,\%args);
+        $data = $self->_convert_input("CeaseADSLOrder" ,\%args);
     }
     else {
         my %adsl = $self->adslaccount(%args);
@@ -812,16 +812,16 @@ sub cease {
     my $d = Time::Piece->strptime($args{"crd"}, "%F");
     $data->{"ceaseDate"} = $d->dmy('/');
     
-    my $response = $self->make_request("CeaseADSLOrder", $data);
+    my $response = $self->_make_request("CeaseADSLOrder", $data);
 
     die "Cease order not accepted by Enta" unless $response->{Response}->{Type} eq 'Accept';
 
     return $response->{Response}->{OperationResponse}->{OurRef};
 }
 
-=head2 requestmac
+=head2 request_mac
 
-    $enta->requestmac( "service-id" => 'ADSL12345');
+    $enta->request_mac( "service-id" => 'ADSL12345');
 
 Obtains a MAC for the given service. 
 
@@ -844,9 +844,9 @@ sub request_mac {
 
     %args = ( "ref" => $adsl{adslaccount}->{ourref} );
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     
-    my $response = $self->make_request("RequestMAC", $data );
+    my $response = $self->_make_request("RequestMAC", $data );
 
     return ( "mac_requested" => 1 );
 }
@@ -863,9 +863,9 @@ sub auth_log {
     my ($self, %args) = @_;
     $self->_check_params(\%args);
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     
-    my $response = $self->make_request("LastRadiusLog", $data );
+    my $response = $self->_make_request("LastRadiusLog", $data );
 
     my %log = ();
     my @r = ();
@@ -896,9 +896,9 @@ sub max_reports {
     my ($self, %args) = @_;
     $self->_check_params(\%args, ("ref|telephone|username|service-id"));
     
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
 
-    my $response = $self->make_request("GetMaxReports", $data);
+    my $response = $self->_make_request("GetMaxReports", $data);
 
     my %line = ();
     my @rate = ();
@@ -977,7 +977,7 @@ sub getadslinstall {
     my ($self, %args) = @_;
     $self->_check_params(\%args, ( 'username' ) );
 
-    my $response = $self->make_request("GetAdslInstall", \%args);
+    my $response = $self->_make_request("GetAdslInstall", \%args);
 
     my $dateformat = "%Y-%m-%d";
     $dateformat = $args{dateformat} if $args{dateformat};
@@ -1033,9 +1033,9 @@ sub adslaccount {
     my ($self, %args) = @_;
     $self->_check_params(\%args, ( "service-id|telephone|ref|username" ));
     
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
     
-    my $response = $self->make_request("AdslAccount", $data );
+    my $response = $self->_make_request("AdslAccount", $data );
 
     my %adsl = ();
     foreach (keys %{$response->{Response}->{OperationResponse}} ) {
@@ -1118,9 +1118,9 @@ sub order {
     my $d = Time::Piece->strptime($args{"crd"}, "%F");
     $args{"crd"} = $d->dmy("/");
 
-    my $data = $self->convert_input("CreateADSLOrder", \%args);
+    my $data = $self->_convert_input("CreateADSLOrder", \%args);
 
-    my $response = $self->make_request("CreateADSLOrder", $data);
+    my $response = $self->_make_request("CreateADSLOrder", $data);
 
     return ( "order_id" => $response->{Response}->{OperationResponse}->{OurRef},
              "service_id" => $response->{Response}->{OperationResponse}->{OurRef},
@@ -1163,8 +1163,8 @@ sub product_change {
 
     $args{schedule} = "FirstAvailableDate";
 
-    my $data = $self->convert_input("ProductChange", \%args);
-    my $response = $self->make_request("ProductChange", $data);
+    my $data = $self->_convert_input("ProductChange", \%args);
+    my $response = $self->_make_request("ProductChange", $data);
 
     return $response->{Response}->{OperationResponse}->{ProductChange}->{Results};
 }
@@ -1227,7 +1227,7 @@ sub usage_summary {
     my ($self, %args) = @_;
     $self->_check_params(\%args, ("service-id|ref|username|telephone"));
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
 
     my $s = $args{year}."-".$args{month}."-1";
     my $start = Time::Piece->strptime($s, "%F");
@@ -1260,6 +1260,12 @@ sub usage_summary {
     );
 }
 
+=head2 usage_history
+
+    $enta->usage_history(startdatetime => '2010-01-01', enddatetime => '2010-12-01');
+
+=cut
+
 sub usage_history {
     my ($self, %args) = @_;
     $self->_check_params(\%args, (qw/startdatetime enddatetime/));
@@ -1273,11 +1279,11 @@ sub usage_history {
         $args{enddatetime} = $s->dmy('/') . ' ' . $s->strftime("%H:%M:%S");
     }
 
-    my $data = $self->convert_input("UsageHistory", \%args);
+    my $data = $self->_convert_input("UsageHistory", \%args);
 
     $data->{RawDisplay} = 1;
 
-    my $response = $self->make_request("UsageHistory", $data);
+    my $response = $self->_make_request("UsageHistory", $data);
 
     my $s = Time::Piece->strptime($response->{Response}->{OperationResponse}->{StartDateTime}, "%d %b %Y %H:%M:%S");
     my $e = Time::Piece->strptime($response->{Response}->{OperationResponse}->{EndDateTime}, "%d %b %Y %H:%M:%S");
@@ -1346,7 +1352,7 @@ Data returned per 10 minute interval for a day:
 sub usage_history_detail {
     my ($self, %args) = @_;
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
 
     if ( $args{"day"} ) {
         my $d = Time::Piece->strptime($args{"day"}, "%F");
@@ -1365,7 +1371,7 @@ sub usage_history_detail {
     my $date_format = "%Y-%m-%d";
     $date_format = $args{dateformat} if $args{dateformat};
 
-    my $response = $self->make_request("UsageHistoryDetail", $data);
+    my $response = $self->_make_request("UsageHistoryDetail", $data);
 
     my @usage = ();
     if ( $args{"day"} ) {
@@ -1425,7 +1431,7 @@ sub allowance {
     for (qw/telephone ref username/) {
         $data->{$_} = $args{$_} if $args{$_};
     }
-    my $response = $self->make_request("ADSLTopup", $data );
+    my $response = $self->_make_request("ADSLTopup", $data );
 
     return %{$response->{Response}->{OperationResponse}};
 }
@@ -1464,7 +1470,7 @@ sub connectionhistory {
         $data = { "username" => $adsl{adslaccount}->{username} };
     }
     else {
-        $data = $self->serviceid(\%args);
+        $data = $self->_serviceid(\%args);
     }
 
     $data->{days} = $args{days} if $args{days};
@@ -1472,7 +1478,7 @@ sub connectionhistory {
     my $date_format = "%Y-%m-%d %H:%M:%S";
     $date_format = $args{dateformat} if $args{dateformat};
 
-    my $response = $self->make_request("ConnectionHistory", $data);
+    my $response = $self->_make_request("ConnectionHistory", $data);
     
     my @history = ();
 
@@ -1541,9 +1547,9 @@ sub case_search {
     my ( $self, %args ) = @_;
     $self->_check_params(\%args, qw/ref|username|service-id/);
 
-    my $data = $self->serviceid(\%args);
+    my $data = $self->_serviceid(\%args);
 
-    my $response = $self->make_request("GetNotes", $data);
+    my $response = $self->_make_request("GetNotes", $data);
 
     my @c = ();
     my $date_format = "%Y-%m-%d %H:%M:%S";
